(function() {


// @TODO: IE compatibility: make sure no spurious "," at end.
var mappings = [

  {
    // Canonization: convert to uppercase.
    'a': 'A',
    'i': 'I',
    'u': 'U',
    'p': 'P',
    'v': 'V'
  },

  {
    // Canonization: get rid of Hebrew's suffixes.
    'ן': 'נ',
    'ם': 'מ',
    'ך': 'כ',
    'ף': 'פ',
    'ץ': 'צ'
  },

  {
    // Alifs.
    'אA': 'أ',
    'אI': 'إ',
    'אU': 'أU',
    'א:': 'أ:',
    'א#': 'ى',  // alif maksura.
    'א~': 'ٱ',  // HamzatWasl  http://he.wikibooks.org/wiki/ערבית/ספרותית/أل_הידיעה
    'א~~': "آ"  // Alif madda. There's also "\u0653" for madda alone.
    // @todo: what about the alif in "hadha"?
  },

  {
    // Hamza.
    'ו@': 'ؤ',
    'י@': 'ئ'
  },

  {
    '@': 'ﺀ',
    'א': 'ا',
    'ב': 'ب',
    'ג': 'ج',
      "ג'": 'ج',
    'ד': 'د',
    "ד'": 'ذ',
    'ה': 'ه',
    'ו': 'و',
    'ז': 'ز',
    'ח': 'ح',
    "ח'": 'خ',
    'ט': 'ط',
      "ט'": 'ظ',
    'י': 'ي',
    'כ': 'ك',
    'ל': 'ل',
    'מ': 'م',
    'נ': 'ن',
    'ס': 'س',
    'ע': 'ع',
      "ע'": 'غ',
    'פ': 'ف',
    'צ': 'ص',
      "צ'": 'ض',
    'ק': 'ق',
    'ר': 'ر',
    'ש': 'ش',
    'ת': 'ت',
    "ת'": 'ث',
    'ה~': 'ة',

    // non-Arab letters:
    'P': 'پ',
    'V': 'ڨ'
  },

  {
    // Vowels.
    //
    // (See http://corpus.quran.com/java/unicode.jsp)
    '*': "\u0651", // shadda
    ':': "\u0652", // sukun
    'A': "\u064E", // fatha
    'U': "\u064F", // damma
    'I': "\u0650", // kasra
    'AA': "\u064B", // fathatan
    'UU': "\u064C", // dammatan
    'II': "\u064D" // kasratan
  },

  {
    // Punctuations.
    ';': '؛',
    ',': '،',
    '.': '.',
    '?': '؟'
  },

  {
    // Miscellaneous.
    '_': 'ـ', // kashida/tatweel
    '0': '٠',
    '1': '١',
    '2': '٢',
    '3': '٣',
    '4': '٤',
    '5': '٥',
    '6': '٦',
    '7': '٧',
    '8': '٨',
    '9': '٩'
  }

];

Keyboard.register(new Keyboard(mappings), 'ar-he');

})();
