
Keyboard = function(mappings) {
  this.mappings = mappings;
  this.build_regexps();
}

Keyboard.prototype.build_regexps = function() {

  this.regexps = [];

  var sort_by_longest_string = function(a, b) {
    return b.length - a.length;
  }

  for (var round in this.mappings) {
    var map = this.mappings[round];
    var letters = [];
    for (var letter in map) {
      letters.push(letter.replace(/([.*?])/g, '\\$1'));
    }
    this.regexps[round] = new RegExp('(' + letters.sort(sort_by_longest_string).join('|') + ')', 'g')
  }
}

Keyboard.prototype.transliterate = function(text) {
  for (var round in this.mappings) {
    var map = this.mappings[round];
    var re = this.regexps[round];
    text = text.replace(re, function(letter) {
      return map[letter];
    });
  }
  return text;
}


Keyboard.registry = {};

// Registers a keyboard.
Keyboard.register = function(kbd, name) {
  Keyboard.registry[name] = kbd;
}

// Retrieves a registered keyboard.
Keyboard.get = function(name) {
  return Keyboard.registry[name];
}

;

// The above terminating ";" is important: if the next statement (e.g., when
// concatenating several JS files) is "(...)", JS will try to execute the
// above function.
